@@ -2,10 +2,10 @@
 
 __author__ = """Tonye Jack"""
 __email__ = "jtonye@ymail.com"
-__version__ = "2.9.6"
+__version__ = "3.0.0"
 
 from model_clone.admin import CloneModelAdmin, CloneModelAdminMixin
-from model_clone.mixins.clone import CloneMixin
+from model_clone.mixin import CloneMixin
 from model_clone.utils import create_copy_of_instance
 
 __all__ = [
